@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "info-nav" "1.0.3"
+(define-package "info-nav" "20260113.531"
   "Browse info docs with a 2 pane layout."
   '((emacs "29.1"))
   :url "https://codeberg.org/ggxx/info-nav"
